@@ -9,20 +9,20 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("2.4.") or
-    raise "ruby lib version (2.4.3) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("2.5.") or
+    raise "ruby lib version (2.5.1) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.4.0/armv5tel-linux-eabi")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.5.0/armv5tel-linux-eabi")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
-  CONFIG["MINOR"] = "4"
-  CONFIG["TEENY"] = "3"
-  CONFIG["PATCHLEVEL"] = "205"
+  CONFIG["MINOR"] = "5"
+  CONFIG["TEENY"] = "1"
+  CONFIG["PATCHLEVEL"] = "57"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr")
@@ -30,12 +30,11 @@ module RbConfig
   CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME)"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-2.4.pc"
+  CONFIG["ruby_pc"] = "ruby-2.5.pc"
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
   CONFIG["USE_RUBYGEMS"] = "YES"
   CONFIG["MANTYPE"] = "doc"
-  CONFIG["NROFF"] = "/usr/bin/nroff"
   CONFIG["vendorarchhdrdir"] = "$(vendorhdrdir)/$(sitearch)"
   CONFIG["sitearchhdrdir"] = "$(sitehdrdir)/$(sitearch)"
   CONFIG["rubyarchhdrdir"] = "$(rubyhdrdir)/$(arch)"
@@ -45,7 +44,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/usr' '--sysconfdir=/etc' '--enable-shared' '--disable-rpath' '--with-dbm-type=gdbm_compat' 'CFLAGS=-march=armv5te -O2 -pipe -fstack-protector-strong -fno-plt' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro' 'CPPFLAGS=-D_FORTIFY_SOURCE=2' 'CXXFLAGS=-march=armv5te -O2 -pipe -fstack-protector-strong -fno-plt'"
+  CONFIG["configure_args"] = " '--prefix=/usr' '--sysconfdir=/etc' '--localstatedir=/var' '--sharedstatedir=/var/lib' '--libexecdir=/usr/lib/ruby' '--enable-shared' '--disable-rpath' '--with-dbm-type=gdbm_compat' 'CFLAGS=-march=armv5te -O2 -pipe -fstack-protector-strong -fno-plt' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro' 'CPPFLAGS=-D_FORTIFY_SOURCE=2' 'CXXFLAGS=-march=armv5te -O2 -pipe -fstack-protector-strong -fno-plt'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -55,7 +54,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "2.4.0"
+  CONFIG["ruby_version"] = "2.5.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "armv5tel-linux-eabi"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -86,18 +85,20 @@ module RbConfig
   CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static"
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
-  CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so.$(MAJOR).$(MINOR) lib$(RUBY_SO_NAME).so"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.$(RUBY_PROGRAM_VERSION)"
+  CONFIG["LIBRUBY_ALIASES"] = "$(LIBRUBY_SONAME) lib$(RUBY_SO_NAME).$(SOEXT)"
+  CONFIG["LIBRUBY_SONAME"] = "lib$(RUBY_SO_NAME).$(SOEXT).$(RUBY_API_VERSION)"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).$(SOEXT).$(RUBY_PROGRAM_VERSION)"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = "-std=gnu99"
-  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wno-tautological-compare -Wno-parentheses-equality -Wno-constant-logical-operand -Wno-self-assign -Wunused-variable -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wimplicit-function-declaration -Wdeprecated-declarations -Wno-packed-bitfield-compat -Wsuggest-attribute=noreturn -Wsuggest-attribute=format -Wimplicit-fallthrough=0"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wno-tautological-compare -Wno-parentheses-equality -Wno-constant-logical-operand -Wno-self-assign -Wunused-variable -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wimplicit-function-declaration -Wdeprecated-declarations -Wmisleading-indentation -Wno-packed-bitfield-compat -Wsuggest-attribute=noreturn -Wsuggest-attribute=format -Wimplicit-fallthrough=0 -Wduplicated-cond -Wrestrict"
   CONFIG["debugflags"] = "-ggdb3"
-  CONFIG["optflags"] = "-O3 -fno-fast-math"
+  CONFIG["optflags"] = "-O3"
   CONFIG["NULLCMD"] = ":"
+  CONFIG["ENABLE_DEBUG_ENV"] = ""
   CONFIG["DLNOBJ"] = "dln.o"
   CONFIG["INSTALL_STATIC_LIBRARY"] = "no"
   CONFIG["EXECUTABLE_EXTS"] = ""
@@ -112,6 +113,7 @@ module RbConfig
   CONFIG["ENCSTATIC"] = ""
   CONFIG["EXTSTATIC"] = ""
   CONFIG["STRIP"] = "strip -S -x"
+  CONFIG["SOEXT"] = "so"
   CONFIG["TRY_LINK"] = ""
   CONFIG["PRELOADENV"] = "LD_PRELOAD"
   CONFIG["LIBPATHENV"] = "LD_LIBRARY_PATH"
@@ -129,6 +131,7 @@ module RbConfig
   CONFIG["ARCH_FLAG"] = ""
   CONFIG["DLDFLAGS"] = "-Wl,-O1,--sort-common,--as-needed,-z,relro -Wl,--compress-debug-sections=zlib"
   CONFIG["ALLOCA"] = ""
+  CONFIG["dsymutil"] = ""
   CONFIG["codesign"] = ""
   CONFIG["POSTLINK"] = ":"
   CONFIG["WERRORFLAG"] = "-Werror"
@@ -138,8 +141,7 @@ module RbConfig
   CONFIG["RMDIR"] = "rmdir --ignore-fail-on-non-empty"
   CONFIG["CP"] = "cp"
   CONFIG["RM"] = "rm -f"
-  CONFIG["PKG_CONFIG"] = "/usr/bin/pkg-config"
-  CONFIG["PYTHON"] = ""
+  CONFIG["PKG_CONFIG"] = "pkg-config"
   CONFIG["DOXYGEN"] = "doxygen"
   CONFIG["DOT"] = "dot"
   CONFIG["MAKEDIRS"] = "/usr/bin/mkdir -p"
@@ -160,7 +162,7 @@ module RbConfig
   CONFIG["AR"] = "ar"
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "gcc (GCC) 7.2.1 20171128\nCopyright (C) 2017 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
+  CONFIG["CC_VERSION_MESSAGE"] = "armv5tel-unknown-linux-gnueabi-gcc (GCC) 7.3.1 20180312\nCopyright (C) 2017 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
@@ -173,16 +175,12 @@ module RbConfig
   CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["CPP"] = "$(CC) -E"
   CONFIG["CXXFLAGS"] = "-march=armv5te -O2 -pipe -fstack-protector-strong -fno-plt"
+  CONFIG["CXX"] = "g++"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-D_FORTIFY_SOURCE=2 $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -Wl,-O1,--sort-common,--as-needed,-z,relro -fstack-protector -rdynamic -Wl,-export-dynamic"
   CONFIG["CFLAGS"] = "-march=armv5te -O2 -pipe -fstack-protector-strong -fno-plt -fPIC"
-  CONFIG["CXX"] = "g++"
   CONFIG["CC"] = "gcc"
-  CONFIG["NACL_LIB_PATH"] = ""
-  CONFIG["NACL_SDK_VARIANT"] = ""
-  CONFIG["NACL_SDK_ROOT"] = ""
-  CONFIG["NACL_TOOLCHAIN"] = ""
   CONFIG["target_os"] = "linux-eabi"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "armv5tel"
@@ -198,7 +196,10 @@ module RbConfig
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "armv5tel"
   CONFIG["build"] = "armv5tel-unknown-linux-gnueabi"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.4.3"
+  CONFIG["RUBY_API_VERSION"] = "$(MAJOR).$(MINOR)"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.5.1"
+  CONFIG["HAVE_GIT"] = "no"
+  CONFIG["GIT"] = "git"
   CONFIG["cxxflags"] = "$(optflags) $(debugflags) $(warnflags)"
   CONFIG["cppflags"] = ""
   CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
@@ -221,12 +222,12 @@ module RbConfig
   CONFIG["docdir"] = "$(datarootdir)/doc/$(PACKAGE)"
   CONFIG["oldincludedir"] = "/usr/include"
   CONFIG["includedir"] = "$(prefix)/include"
-  CONFIG["localstatedir"] = "$(prefix)/var"
-  CONFIG["sharedstatedir"] = "$(prefix)/com"
+  CONFIG["localstatedir"] = "$(DESTDIR)/var"
+  CONFIG["sharedstatedir"] = "$(DESTDIR)/var/lib"
   CONFIG["sysconfdir"] = "$(DESTDIR)/etc"
   CONFIG["datadir"] = "$(datarootdir)"
   CONFIG["datarootdir"] = "$(prefix)/share"
-  CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
+  CONFIG["libexecdir"] = "$(DESTDIR)/usr/lib/ruby"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
   CONFIG["exec_prefix"] = "$(prefix)"
@@ -238,7 +239,7 @@ module RbConfig
   CONFIG["PACKAGE_NAME"] = ""
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["SHELL"] = "/bin/sh"
-  CONFIG["UNICODE_VERSION"] = "9.0.0"
+  CONFIG["UNICODE_VERSION"] = "10.0.0"
   CONFIG["archdir"] = "$(rubyarchdir)"
   CONFIG["topdir"] = File.dirname(__FILE__)
   # Almost same with CONFIG. MAKEFILE_CONFIG has other variable
